==> nextcloud-26.0.10.tgz: nextcloud/lib/l10n/si.js <==
OC.L10N.register(
    "lib",
    {
    "See %s" : "%s බලන්න",
    "Other activities" : "වෙනත්  ක්‍රියාකාරකම්",
    "%1$s and %2$s" : "%1$s සහ %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s සහ %3$s ",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s සහ %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s සහ %5$s",
    "Authentication" : "සත්‍යාපනය",
    "Invalid image" : "වලංගු නොවන පින්තූරයකි",
    "Files" : "ගොනු",
    "today" : "අද",
    "tomorrow" : "හෙට",
    "yesterday" : "ඊයේ",
    "seconds ago" : "තත්පර කිහිපයකට පෙර",
    "Empty file" : "හිස් ගොනුවකි",
    "File already exists" : "ගොනුව දැනටමත් පවතී",
    "File name is too long" : "ගොනුවේ නම දිග වැඩිය",
    "__language_name__" : "සිංහල",
    "This is an automatically sent email, please do not reply." : "මෙය ස්වයංක්‍රීයව යවන ලද විද්‍යුත් තැපෑලකි, කරුණාකර පිළිතුරු නොදෙන්න.",
    "Help" : "උපකාර",
    "Apps" : "යෙදුම්",
    "Settings" : "සැකසුම්",
    "Log out" : "නික්මෙන්න",
    "Users" : "පරිශීලකයින්",
    "Email" : "විද්‍යුත් තැපෑල",
    "Phone" : "දුරකථනය",
    "Twitter" : "ට්විටර්",
    "Website" : "වියමන අඩවිය",
    "Address" : "ලිපිනය",
    "About" : "පිළිබඳව",
    "Role" : "කාර්යභාරය",
    "Unknown user" : "නොදන්නා පරිශීලකයෙකි",
    "Additional settings" : "අමතර සැකසුම්",
    "Sunday" : "ඉරිදා",
    "Monday" : "සඳුදා",
    "Tuesday" : "අඟහරුවාදා",
    "Wednesday" : "බදාදා",
    "Thursday" : "බ්‍රහස්පතින්දා",
    "Friday" : "සිකුරාදා",
    "Saturday" : "සෙනසුරාදා",
    "Sun." : "ඉරි.",
    "Mon." : "සඳු.",
    "Tue." : "අඟ.",
    "Wed." : "බදා.",
    "Thu." : "බ්‍රහ.",
    "Fri." : "සිකු.",
    "Sat." : "සෙන.",
    "Su" : "ඉරි",
    "Mo" : "සඳු",
    "Tu" : "අඟ",
    "We" : "බදා",
    "Th" : "බ්‍රහ",
    "Fr" : "සිකු",
    "Sa" : "සෙන",
    "January" : "ජනවාරි",
    "February" : "පෙබරවාරි",
    "March" : "මාර්තු",
    "April" : "අප්‍රේල්",
    "May" : "මැයි",
    "June" : "ජූනි",
    "July" : "ජුලි",
    "August" : "අගෝස්තු",
    "September" : "සැප්තැම්බර්",
    "October" : "ඔක්තෝම්බර්",
    "November" : "නොවැම්බර්",
    "December" : "දෙසැම්බර්",
    "Full name" : "සම්පූර්ණ නම"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-27.1.7p0.tgz: nextcloud/lib/l10n/si.js <==
OC.L10N.register(
    "lib",
    {
    "See %s" : "%s බලන්න",
    "Other activities" : "වෙනත්  ක්‍රියාකාරකම්",
    "%1$s and %2$s" : "%1$s සහ %2$s",
    "%1$s, %2$s and %3$s" : "%1$s, %2$s සහ %3$s ",
    "%1$s, %2$s, %3$s and %4$s" : "%1$s, %2$s, %3$s සහ %4$s",
    "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s, %2$s, %3$s, %4$s සහ %5$s",
    "Authentication" : "සත්‍යාපනය",
    "Invalid image" : "වලංගු නොවන පින්තූරයකි",
    "Files" : "ගොනු",
    "today" : "අද",
    "tomorrow" : "හෙට",
    "yesterday" : "ඊයේ",
    "seconds ago" : "තත්පර කිහිපයකට පෙර",
    "Empty file" : "හිස් ගොනුවකි",
    "File already exists" : "ගොනුව දැනටමත් පවතී",
    "File name is too long" : "ගොනුවේ නම දිග වැඩිය",
    "__language_name__" : "සිංහල",
    "This is an automatically sent email, please do not reply." : "මෙය ස්වයංක්‍රීයව යවන ලද විද්‍යුත් තැපෑලකි, කරුණාකර පිළිතුරු නොදෙන්න.",
    "Help" : "උපකාර",
    "Apps" : "යෙදුම්",
    "Settings" : "සැකසුම්",
    "Log out" : "නික්මෙන්න",
    "Users" : "පරිශීලකයින්",
    "Email" : "විද්‍යුත් තැපෑල",
    "Phone" : "දුරකථනය",
    "Twitter" : "ට්විටර්",
    "Website" : "වියමන අඩවිය",
    "Address" : "ලිපිනය",
    "About" : "පිළිබඳව",
    "Role" : "කාර්යභාරය",
    "Additional settings" : "අමතර සැකසුම්",
    "Sunday" : "ඉරිදා",
    "Monday" : "සඳුදා",
    "Tuesday" : "අඟහරුවාදා",
    "Wednesday" : "බදාදා",
    "Thursday" : "බ්‍රහස්පතින්දා",
    "Friday" : "සිකුරාදා",
    "Saturday" : "සෙනසුරාදා",
    "Sun." : "ඉරි.",
    "Mon." : "සඳු.",
    "Tue." : "අඟ.",
    "Wed." : "බදා.",
    "Thu." : "බ්‍රහ.",
    "Fri." : "සිකු.",
    "Sat." : "සෙන.",
    "Su" : "ඉරි",
    "Mo" : "සඳු",
    "Tu" : "අඟ",
    "We" : "බදා",
    "Th" : "බ්‍රහ",
    "Fr" : "සිකු",
    "Sa" : "සෙන",
    "January" : "ජනවාරි",
    "February" : "පෙබරවාරි",
    "March" : "මාර්තු",
    "April" : "අප්‍රේල්",
    "May" : "මැයි",
    "June" : "ජූනි",
    "July" : "ජුලි",
    "August" : "අගෝස්තු",
    "September" : "සැප්තැම්බර්",
    "October" : "ඔක්තෝම්බර්",
    "November" : "නොවැම්බර්",
    "December" : "දෙසැම්බර්",
    "Full name" : "සම්පූර්ණ නම",
    "Unknown user" : "නොදන්නා පරිශීලකයෙකි"
},
"nplurals=2; plural=(n != 1);");
